==> pyphant-0.8a2.tar.gz: pyphant-0.8a2/pyphant/wxgui2/paramvisualization/FileButton.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2006-2007, Rectorate of the University of Freiburg
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# * Neither the name of the Freiburg Materials Research Center,
#   University of Freiburg nor the names of its contributors may be used to
#   endorse or promote products derived from this software without specific
#   prior written permission.
#
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

u"""
"""

__id__ = "$Id$"
__author__ = "$Author$"
__version__ = "$Revision$"
# $Source$

import wx, os.path

class FileButton(wx.Button):
    def __init__(self, parent, param, validator):
        self.path=os.path.abspath(param.value)
        self.dir, self.filename=os.path.split(self.path)
        wx.Button.__init__(self, parent, label=self.filename, validator=validator)
        self.Bind(wx.EVT_BUTTON, self.selectFile)

    def selectFile(self, event):
        dir = filename = wx.EmptyString
        if os.path.exists(self.dir):
            dir = self.dir
            if os.path.exists(os.path.join(self.dir, self.filename)):
                filename = self.filename
        dlg=wx.FileDialog(self, message="Choose a file", defaultDir=dir,
                          defaultFile=filename, style=wx.OPEN)
        if dlg.ShowModal() == wx.ID_OK:
            self.path=os.path.abspath(dlg.GetPath())
            self.dir, self.filename=os.path.split(self.path)
            self.SetLabel(self.filename)

    def getValue(self):
        return self.path

    def SetValue(self, path):
        self.path=path
        self.dir, self.filename=os.path.split(self.path)
        self.SetLabel(self.filename)

==> pyphant-1.0b1.tar.gz: pyphant-1.0b1/pyphant/wxgui2/paramvisualization/FileButton.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2006-2007, Rectorate of the University of Freiburg
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# * Redistributions of source code must retain the above copyright
#   notice, this list of conditions and the following disclaimer.
# * Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in the
#   documentation and/or other materials provided with the distribution.
# * Neither the name of the Freiburg Materials Research Center,
#   University of Freiburg nor the names of its contributors may be used to
#   endorse or promote products derived from this software without specific
#   prior written permission.
#
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

u"""
"""

__id__ = "$Id$"
__author__ = "$Author$"
__version__ = "$Revision$"
# $Source$

import wx, os.path

class FileButton(wx.Button):
    def __init__(self, parent, param, validator):
        self.path=os.path.abspath(param.value)
        self.dir, self.filename=os.path.split(self.path)
        wx.Button.__init__(self, parent,
                           label=self.filename,
                           validator=validator)
        self.Bind(wx.EVT_BUTTON, self.selectFile)
        self.param = param

    def selectFile(self, event):
        dir = filename = wx.EmptyString
        if os.path.exists(self.dir):
            dir = self.dir
            if os.path.exists(os.path.join(self.dir, self.filename)):
                filename = self.filename
        dlg = wx.FileDialog(self, message="Choose a file", defaultDir=dir,
                            defaultFile=filename, style=wx.OPEN)
        if hasattr(self.param, "fileMask"):
            dlg.SetWildcard(self.param.fileMask)
        if dlg.ShowModal() == wx.ID_OK:
            self.path=os.path.abspath(dlg.GetPath())
            self.dir, self.filename=os.path.split(self.path)
            self.SetLabel(self.filename)

    def getValue(self):
        return self.path

    def SetValue(self, path):
        self.path=path
        self.dir, self.filename=os.path.split(self.path)
        self.SetLabel(self.filename)
